@@ -2,9 +2,10 @@ package Alien::Role;
 
 use strict;
 use warnings;
+use 5.008004;
 
 # ABSTRACT: Extend Alien::Base with roles!
-our $VERSION = '1.94'; # VERSION
+our $VERSION = '2.37'; # VERSION
 
 
 1;
@@ -21,7 +22,7 @@ Alien::Role - Extend Alien::Base with roles!
 
 =head1 VERSION
 
-version 1.94
+version 2.37
 
 =head1 SYNOPSIS
 
@@ -125,9 +126,11 @@ Shawn Laffan (SLAFFAN)
 
 Paul Evans (leonerd, PEVANS)
 
+Håkon Hægland (hakonhagland, HAKONH)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2019 by Graham Ollis.
+This software is copyright (c) 2011-2020 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
